@@ -48,7 +48,7 @@
 
 #include "cfg/cfg_int.h"
 #include "cfg/dir.h"
-#include "util.h"
+#include "util/util.h"
 #include <openssl/evp.h>
 #include <openssl/hmac.h>
 
@@ -1176,11 +1176,11 @@ static char *test_proto_validate_jwt(request_rec *r) {
 
 	oidc_jwk_t *jwk = NULL;
 	TST_ASSERT_ERR("oidc_util_create_symmetric_key",
-		       oidc_util_create_symmetric_key(r, s_secret, 0, NULL, TRUE, &jwk) == TRUE, r->pool, err);
+		       oidc_util_key_symmetric_create(r, s_secret, 0, NULL, TRUE, &jwk) == TRUE, r->pool, err);
 	TST_ASSERT_ERR("oidc_util_create_symmetric_key (jwk)", jwk != NULL, r->pool, err);
 
 	TST_ASSERT_ERR("oidc_jwt_verify",
-		       oidc_jwt_verify(r->pool, jwt, oidc_util_merge_symmetric_key(r->pool, NULL, jwk), &err), r->pool,
+		       oidc_jwt_verify(r->pool, jwt, oidc_util_key_symmetric_merge(r->pool, NULL, jwk), &err), r->pool,
 		       err);
 
 	TST_ASSERT_ERR("oidc_proto_validate_jwt", oidc_proto_jwt_validate(r, jwt, s_issuer, TRUE, TRUE, 10), r->pool,
@@ -1199,61 +1199,59 @@ static char *test_current_url(request_rec *r) {
 	r->uri = "/test";
 	r->unparsed_uri = apr_pstrcat(r->pool, r->uri, "?", r->args, NULL);
 
-	url = oidc_util_current_url(r, 0);
+	url = oidc_util_url_cur(r, 0);
 	TST_ASSERT_STR("test_current_url (1)", url, "https://www.example.com/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Host", "www.outer.com");
-	url = oidc_util_current_url(r, 0);
+	url = oidc_util_url_cur(r, 0);
 	TST_ASSERT_STR("test_current_url (2a)", url, "https://www.example.com/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST);
 	TST_ASSERT_STR("test_current_url (2b)", url, "https://www.outer.com/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Host", "www.outer.com:654");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST);
 	TST_ASSERT_STR("test_current_url (3)", url, "https://www.outer.com:654/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Port", "321");
-	url = oidc_util_current_url(r, 0);
+	url = oidc_util_url_cur(r, 0);
 	TST_ASSERT_STR("test_current_url (4a)", url, "https://www.example.com/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST);
 	TST_ASSERT_STR("test_current_url (4b)", url, "https://www.outer.com:654/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT);
 	TST_ASSERT_STR("test_current_url (4)", url, "https://www.outer.com:321/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Proto", "http");
-	url = oidc_util_current_url(r, 0);
+	url = oidc_util_url_cur(r, 0);
 	TST_ASSERT_STR("test_current_url (5a)", url, "https://www.example.com/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST);
 	TST_ASSERT_STR("test_current_url (5b)", url, "https://www.outer.com:654/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT);
 	TST_ASSERT_STR("test_current_url (5c)", url, "https://www.outer.com:321/test?foo=bar&param1=value1");
-	url = oidc_util_current_url(r,
-				    OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT | OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT | OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (5d)", url, "http://www.outer.com:321/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Proto", "https , http");
-	url = oidc_util_current_url(r,
-				    OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT | OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_HOST | OIDC_HDR_X_FORWARDED_PORT | OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (6)", url, "https://www.outer.com:321/test?foo=bar&param1=value1");
 
 	apr_table_unset(r->headers_in, "X-Forwarded-Host");
 	apr_table_unset(r->headers_in, "X-Forwarded-Port");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (7)", url, "https://www.example.com/test?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "X-Forwarded-Proto", "http ");
 	apr_table_set(r->headers_in, "Host", "remotehost:8380");
 	r->uri = "http://remotehost:8380/private/";
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (8)", url, "http://remotehost:8380/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Host", "[fd04:41b1:1170:28:16b0:446b:9fb7:7118]:8380");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (9)", url,
 		       "http://[fd04:41b1:1170:28:16b0:446b:9fb7:7118]:8380/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Host", "[fd04:41b1:1170:28:16b0:446b:9fb7:7118]");
-	url = oidc_util_current_url(r, OIDC_HDR_X_FORWARDED_PROTO);
+	url = oidc_util_url_cur(r, OIDC_HDR_X_FORWARDED_PROTO);
 	TST_ASSERT_STR("test_current_url (10)", url,
 		       "http://[fd04:41b1:1170:28:16b0:446b:9fb7:7118]/private/?foo=bar&param1=value1");
 
@@ -1261,29 +1259,29 @@ static char *test_current_url(request_rec *r) {
 	apr_table_unset(r->headers_in, "Host");
 
 	apr_table_set(r->headers_in, "Forwarded", "host=www.outer.com");
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (11)", url, "https://www.outer.com/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Forwarded", "proto=http");
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (12)", url, "http://www.example.com/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Forwarded", "host=www.outer.com:8443");
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (13)", url, "https://www.outer.com:8443/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Forwarded", "proto=http; host=www.outer.com:8080");
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (14)", url, "http://www.outer.com:8080/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Forwarded", "host=www.outer.com:8080; proto=http");
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (15)", url, "http://www.outer.com:8080/private/?foo=bar&param1=value1");
 
 	apr_table_unset(r->headers_in, "Forwarded");
 
 	// it should not crash when Forwarded is not present
-	url = oidc_util_current_url(r, OIDC_HDR_FORWARDED);
+	url = oidc_util_url_cur(r, OIDC_HDR_FORWARDED);
 	TST_ASSERT_STR("test_current_url (16)", url, "https://www.example.com/private/?foo=bar&param1=value1");
 
 	apr_table_set(r->headers_in, "Host", "www.example.com");
@@ -1557,11 +1555,11 @@ static char *test_authz_worker(request_rec *r) {
 static char *test_decode_json_object(request_rec *r) {
 	apr_byte_t rc = FALSE;
 	json_t *json = NULL;
-	rc = oidc_util_decode_json_object(r, "nojson", &json);
+	rc = oidc_util_json_decode_object(r, "nojson", &json);
 	TST_ASSERT("test invalid JSON", rc == FALSE);
-	rc = oidc_util_decode_json_object(r, "{ \"n\": \"\\u0000<?php echo 'Hello' ?>\"}", &json);
+	rc = oidc_util_json_decode_object(r, "{ \"n\": \"\\u0000<?php echo 'Hello' ?>\"}", &json);
 	TST_ASSERT("test JSON with NULL value", rc == FALSE);
-	rc = oidc_util_decode_json_object(
+	rc = oidc_util_json_decode_object(
 	    r,
 	    "tmjcbnuvyrtygbtbyizkfuabiddgixcvnvupjuwnvxznpspmjaqrlpgmggixxovrpwntkvsvxjtkjjggnevyfyemdrlxtnmzjstmjuyquy"
 	    "yjzzwsfrazgzbdojkcfaeiqawltqsiwwzzgpiikpqoxixhsqtnfbchrcgxbgiaynkscvbvfnpuddrpjbgdtxxlebrswrtukzxqyyfrmwrr"
@@ -1604,7 +1602,7 @@ static char *test_decode_json_object(request_rec *r) {
 	    "enkhkiuojxdwscvtacbwfixhrcaxlfeakidxgrmgitrmrzdzhwjyazzikrclajgksENDxxxx",
 	    &json);
 	TST_ASSERT("test invalid long JSON", rc == FALSE);
-	rc = oidc_util_decode_json_object(r, "{}", &json);
+	rc = oidc_util_json_decode_object(r, "{}", &json);
 	TST_ASSERT("test valid JSON", rc == TRUE);
 	json_decref(json);
 	return 0;
@@ -1617,7 +1615,7 @@ static char *test_remote_user(request_rec *r) {
 	json_t *json = NULL;
 
 	s = "{\"upn\":\"nneul@umsystem.edu\"}";
-	rc = oidc_util_decode_json_object(r, s, &json);
+	rc = oidc_util_json_decode_object(r, s, &json);
 	TST_ASSERT("test remote user (1) valid JSON", rc == TRUE);
 	rc = oidc_get_remote_user(r, "upn", "^(.*)@umsystem\\.edu", NULL, json, &remote_user);
 	TST_ASSERT_STR("remote_user (0) string", remote_user, "nneul");
@@ -1627,7 +1625,7 @@ static char *test_remote_user(request_rec *r) {
 	json_decref(json);
 
 	s = "{\"email\":\"nneul@umsystem.edu\"}";
-	rc = oidc_util_decode_json_object(r, s, &json);
+	rc = oidc_util_json_decode_object(r, s, &json);
 	TST_ASSERT("test remote user (2) valid JSON", rc == TRUE);
 	rc = oidc_get_remote_user(r, "email", "^(.*)@([^.]+)\\..+$", "$2\\$1", json, &remote_user);
 	TST_ASSERT("test remote user (2) function result", rc == TRUE);
@@ -1635,7 +1633,7 @@ static char *test_remote_user(request_rec *r) {
 	json_decref(json);
 
 	s = "{ \"name\": \"Dominik František Bučík\" }";
-	rc = oidc_util_decode_json_object(r, s, &json);
+	rc = oidc_util_json_decode_object(r, s, &json);
 	TST_ASSERT("test remote user (3) valid JSON", rc == TRUE);
 	rc = oidc_get_remote_user(r, "name", "^(.*)$", "$1@test.com", json, &remote_user);
 	TST_ASSERT("test remote user (3) function result", rc == TRUE);
@@ -1643,7 +1641,7 @@ static char *test_remote_user(request_rec *r) {
 	json_decref(json);
 
 	s = "{ \"preferred_username\": \"dbucik\" }";
-	rc = oidc_util_decode_json_object(r, s, &json);
+	rc = oidc_util_json_decode_object(r, s, &json);
 	TST_ASSERT("test remote user (4) valid JSON", rc == TRUE);
 	rc = oidc_get_remote_user(r, "preferred_username", "^(.*)$", "$1@test.com", json, &remote_user);
 	TST_ASSERT("test remote user (4) function result", rc == TRUE);
@@ -1742,7 +1740,7 @@ static char *test_set_app_infos(request_rec *r) {
 	apr_byte_t rc = FALSE;
 	json_t *claims = NULL;
 
-	rc = oidc_util_decode_json_object(r,
+	rc = oidc_util_json_decode_object(r,
 					  "{"
 					  "\"simple\":\"hans\","
 					  "\"name\": \"GÜnther\","
@@ -1751,18 +1749,19 @@ static char *test_set_app_infos(request_rec *r) {
 					  &claims);
 	TST_ASSERT("valid JSON", rc == TRUE);
 
-	oidc_util_set_app_infos(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS, OIDC_APPINFO_ENCODING_NONE);
+	oidc_util_appinfo_set_all(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS, OIDC_APPINFO_ENCODING_NONE);
 	TST_ASSERT_STR("header plain simple", apr_table_get(r->headers_in, "OIDC_CLAIM_simple"), "hans");
 	TST_ASSERT_STR("header plain name", apr_table_get(r->headers_in, "OIDC_CLAIM_name"), "G\u00DCnther");
 	TST_ASSERT_STR("header plain dagger", apr_table_get(r->headers_in, "OIDC_CLAIM_dagger"), "D\u2020gger");
 
-	oidc_util_set_app_infos(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS,
-				OIDC_APPINFO_ENCODING_BASE64URL);
+	oidc_util_appinfo_set_all(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS,
+				  OIDC_APPINFO_ENCODING_BASE64URL);
 	TST_ASSERT_STR("header base64url simple", apr_table_get(r->headers_in, "OIDC_CLAIM_simple"), "aGFucw");
 	TST_ASSERT_STR("header base64url name", apr_table_get(r->headers_in, "OIDC_CLAIM_name"), "R8OcbnRoZXI");
 	TST_ASSERT_STR("header base64url dagger", apr_table_get(r->headers_in, "OIDC_CLAIM_dagger"), "ROKAoGdnZXI");
 
-	oidc_util_set_app_infos(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS, OIDC_APPINFO_ENCODING_LATIN1);
+	oidc_util_appinfo_set_all(r, claims, "OIDC_CLAIM_", ",", OIDC_APPINFO_PASS_HEADERS,
+				  OIDC_APPINFO_ENCODING_LATIN1);
 	TST_ASSERT_STR("header latin1 simple", apr_table_get(r->headers_in, "OIDC_CLAIM_simple"), "hans");
 	TST_ASSERT_STR("header latin1 name", apr_table_get(r->headers_in, "OIDC_CLAIM_name"), "G\xDCnther");
 	TST_ASSERT_STR("header latin1 dagger", apr_table_get(r->headers_in, "OIDC_CLAIM_dagger"), "D?gger");
@@ -1897,8 +1896,10 @@ static request_rec *test_setup(apr_pool_t *pool) {
 
 	oidc_dir_cfg_t *d_cfg = oidc_cfg_dir_config_create(request->pool, NULL);
 
-	request->server->module_config = apr_pcalloc(request->pool, sizeof(void) * kEls);
-	request->per_dir_config = apr_pcalloc(request->pool, sizeof(void) * kEls);
+	// coverity[suspicious_sizeof]
+	request->server->module_config = apr_pcalloc(request->pool, sizeof(void *) * kEls);
+	// coverity[suspicious_sizeof]
+	request->per_dir_config = apr_pcalloc(request->pool, sizeof(void *) * kEls);
 	ap_set_module_config(request->server->module_config, &auth_openidc_module, cfg);
 	ap_set_module_config(request->per_dir_config, &auth_openidc_module, d_cfg);
 
